# GPT Suite
### A collection of tools for working with GPT-3 and GPT-4.

## Building
To build the project, run the following command in the root directory of the project:
```bash
python3 -m build
```

## Installation
Once the project is built, you can install the package by running the following command in the root directory of the project, replacing `x.x.x` with the version number:
```bash
pip install dist/gpt_suite-x.x.x-py3-none-any.whl
```